Package: scattermore
Title: Scatterplots with More Points
Version: 0.7
Authors@R: 
    person(given = "Mirek",
           family = "Kratochvil",
           role = c("aut", "cre"),
           email = "exa.exa@gmail.com",
           comment = c(ORCID = "0000-0001-7356-4075"))
Description: C-based conversion of large scatterplot data to rasters. Speeds up
             plotting of data with millions of points.
URL: https://github.com/exaexa/scattermore
Imports: ggplot2, scales, grid, grDevices, graphics
License: GPL (>= 3)
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.1
NeedsCompilation: yes
Packaged: 2020-11-24 15:54:51 UTC; exa
Author: Mirek Kratochvil [aut, cre] (<https://orcid.org/0000-0001-7356-4075>)
Maintainer: Mirek Kratochvil <exa.exa@gmail.com>
Repository: CRAN
Date/Publication: 2020-11-24 16:30:02 UTC
Built: R 4.0.3; x86_64-w64-mingw32; 2020-12-15 23:52:55 UTC; windows
Archs: x64
