# Generated by roxygen2: do not edit by hand

export(geom_scattermore)
export(geom_scattermost)
export(scattermore)
export(scattermoreplot)
importFrom(ggplot2,Geom)
importFrom(ggplot2,aes)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,draw_key_point)
importFrom(ggplot2,ggproto)
importFrom(ggplot2,layer)
importFrom(grDevices,as.raster)
importFrom(grDevices,col2rgb)
importFrom(grDevices,dev.size)
importFrom(grDevices,rgb)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,rasterImage)
importFrom(grid,rasterGrob)
importFrom(scales,alpha)
useDynLib(scattermore, .registration = TRUE)
